View source: R/bures-wasserstein.R
| bures_wasserstein_exp | R Documentation |
This function computes the Riemannian exponential map using the Bures-Wasserstein metric for symmetric positive-definite matrices. The map operates by solving a Lyapunov equation and then constructing the exponential.
bures_wasserstein_exp(sigma, v, validate = FALSE)
sigma |
A symmetric positive-definite matrix of class |
v |
A symmetric matrix of class |
validate |
A logical value indicating whether to validate input arguments. Default is FALSE. |
A symmetric positive-definite matrix of class dppMatrix, representing the point on the manifold.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.