View source: R/bures-wasserstein.R
| bures_wasserstein_log | R Documentation |
This function computes the Riemannian logarithmic map using the Bures-Wasserstein metric for symmetric positive-definite matrices.
bures_wasserstein_log(sigma, lambda, validate = FALSE)
sigma |
A symmetric positive-definite matrix of class |
lambda |
A symmetric positive-definite matrix of class |
validate |
A logical value indicating whether to validate input arguments. Default is FALSE. |
A symmetric matrix of class dspMatrix, representing the tangent space image of lambda at sigma.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.