View source: R/progress_utils.R
| configure_progress | R Documentation |
Convenience function to configure progressr handlers for the current session.
configure_progress(handler = "txtprogressbar", ...)
handler |
Character string specifying the handler type:
|
... |
Additional arguments passed to |
This is a convenience wrapper around progressr::handlers().
If progressr is not available, a warning is issued and the function returns NULL.
Invisibly returns the configured handlers (via progressr::handlers()).
progressr::handlers()
## Not run:
# Use base R text progress bar
configure_progress("txtprogressbar")
# Use cli style (if cli package is installed)
configure_progress("cli")
# Disable progress reporting
configure_progress("none")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.