| euclidean_exp | R Documentation |
Compute the Euclidean Exponential
euclidean_exp(sigma, v, validate = FALSE)
sigma |
A reference point. |
v |
A tangent vector to be mapped back to the manifold at |
validate |
A logical value indicating whether to validate input arguments. Default is FALSE. |
The point on the manifold corresponding to the tangent vector at sigma.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.