log_euclidean_exp: Compute the Log-Euclidean Exponential

View source: R/log_euclidean.R

log_euclidean_expR Documentation

Compute the Log-Euclidean Exponential

Description

This function computes the Euclidean exponential map.

Usage

log_euclidean_exp(ref_pt, v, validate = FALSE)

Arguments

ref_pt

A reference point.

v

A tangent vector to be mapped back to the manifold at ref_pt.

validate

A logical value indicating whether to validate input arguments. Default is FALSE.

Value

The point on the manifold corresponding to the tangent vector at ref_pt.


riemtan documentation built on Nov. 11, 2025, 1:06 a.m.