| DataBackend | R Documentation |
Abstract base class defining the interface for storage backends. All backend implementations must inherit from this class and implement the required methods.
This class provides a common interface for different storage strategies:
ListBackend: In-memory list storage (current default)
ParquetBackend: Lazy-loaded Parquet files with LRU cache
get_matrix()Get a specific matrix by index
DataBackend$get_matrix(i)
iInteger index of the matrix to retrieve
A dppMatrix object
get_all_matrices()Get all matrices
DataBackend$get_all_matrices()
A list of dppMatrix objects
length()Get the number of matrices
DataBackend$length()
Integer count of matrices
get_dimensions()Get matrix dimensions
DataBackend$get_dimensions()
Integer dimension (p) where matrices are p x p
clone()The objects of this class are cloneable with this method.
DataBackend$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.