| airm_log | R Documentation |
This function computes the Riemannian logarithmic map for the Affine-Invariant Riemannian Metric (AIRM).
airm_log(sigma, lambda, validate = FALSE)
sigma |
A symmetric positive-definite matrix of class |
lambda |
A symmetric positive-definite matrix of class |
validate |
A logical value indicating whether to validate input arguments. Default is FALSE. |
A symmetric matrix of class dspMatrix, representing the tangent space image of lambda at sigma.
if (requireNamespace("Matrix", quietly = TRUE)) {
library(Matrix)
sigma <- diag(2) |>
Matrix::nearPD() |>
_$mat |>
Matrix::pack()
lambda <- diag(c(2, 3)) |>
Matrix::nearPD() |>
_$mat |>
Matrix::pack()
airm_log(sigma, lambda)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.