View source: R/log_euclidean.R
| log_euclidean_exp | R Documentation |
This function computes the Euclidean exponential map.
log_euclidean_exp(ref_pt, v, validate = FALSE)
ref_pt |
A reference point. |
v |
A tangent vector to be mapped back to the manifold at |
validate |
A logical value indicating whether to validate input arguments. Default is FALSE. |
The point on the manifold corresponding to the tangent vector at ref_pt.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.